@@ -3,9 +3,11 @@ mod build;
 mod errors;
 mod exec;
 mod lang;
+pub mod report;
 mod reporter;
 mod result;
 pub mod test;
+pub mod test_runners;
 
 pub use actions::Action;
 pub use actions::Actions;
@@ -15,6 +17,9 @@ pub use actions::TestDataOut;
 pub use errors::Error;
 pub use exec::Executable;
 pub use lang::Language;
-pub use result::TestResult;
+pub use report::Report;
+pub use report::TestCase;
+pub use report::TestSuite;
 pub use reporter::Reporter;
 pub use reporter::SimpleReporter;
+pub use result::TestResult;
